@@ -6,7 +6,7 @@
 #              a PATH.
 # Author:      Sergio Talens-Oliag <sto@debian.org>
 # Copyright:   (c) 2006 Sergio Talens-Oliag <sto@debian.org>
-# SVN Id:      $Id: ssft.sh 73 2006-12-22 18:06:11Z sto $
+# SVN Id:      $Id: ssft.sh 79 2009-06-10 20:01:45Z sto $
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -441,35 +441,51 @@ ssft_progress_bar() {
                   --percentage "$_l_percent" --auto-close
   ;;
   kdialog)
-    _l_kdpbdc="/tmp/kdpbdc-$PID.`date +"%s"`"
-    kdialog --progressbar "$_l_title" 100 > "$_l_kdpbdc" 2> /dev/null
-    DCOPREF=$( sed -n -e '/^DCOPRef/ {
-      s/DCOPRef(\(.*\),ProgressDialog)/\1/;
-      p
-    }' $_l_kdpbdc);
-    rm -f "$_l_kdpbdc"
-    dcop $DCOPREF ProgressDialog setAutoClose true
-    while read _l_line; do
-      _l_percent="`echo $_l_line | sed -n -e '/^[0-9][0-9]*/ {
-        p;
-      };'`"
-      if [ -z "$_l_percent" ]; then
-        dcop $DCOPREF ProgressDialog setLabel "$_l_line" 2> /dev/null;
-      else
-	dcop $DCOPREF ProgressDialog setProgress "$_l_percent" 2> /dev/null;
-      fi
-    done
-    while read _l_line; do
-      _l_percent="`echo $_l_line | sed -n -e '/^[0-9][0-9]*/ {
-        p;
-      };'`"
-      if [ -z "$_l_percent" ]; then
-        _l_text="$_l_line"
-        dcop $DCOPREF ProgressDialog SetLabel "$_l_text"
-      else
-        dcop $DCOPREF ProgressDialog SetPercent "$_l_percent"
-      fi
-    done
+    _l_kdpbref="/tmp/kdpbdc-$PID.`date +"%s"`"
+    kdialog --progressbar "$_l_title" 100 > "$_l_kdpbref" 2> /dev/null
+    if grep -q '^DCOPRef' $_l_kdpbref; then
+      DCOPREF=$( sed -n -e '/^DCOPRef/ {
+        s/DCOPRef(\(.*\),ProgressDialog)/\1/;
+        p
+        }' $_l_kdpbref);
+        rm -f "$_l_kdpbref"
+      dcop $DCOPREF ProgressDialog setAutoClose true
+      while read _l_line; do
+        _l_percent="`echo $_l_line | sed -n -e '/^[0-9][0-9]*/ {
+          p;
+        };'`"
+        if [ -z "$_l_percent" ]; then
+          dcop $DCOPREF ProgressDialog setLabel "$_l_line" 2> /dev/null;
+        else
+	  dcop $DCOPREF ProgressDialog setProgress "$_l_percent" 2> /dev/null;
+        fi
+      done
+      while read _l_line; do
+        _l_percent="`echo $_l_line | sed -n -e '/^[0-9][0-9]*/ {
+          p;
+        };'`"
+        if [ -z "$_l_percent" ]; then
+          _l_text="$_l_line"
+          dcop $DCOPREF ProgressDialog SetLabel "$_l_text"
+        else
+          dcop $DCOPREF ProgressDialog SetPercent "$_l_percent"
+        fi
+      done
+    else
+      DBUSREF=$(cat $_l_kdpbref)
+      rm -f "$_l_kdpbref"
+      qdbus $DBUSREF Set org.kde.kdialog.ProgressDialog autoClose true
+      while read _l_line; do
+	_l_percent="`echo $_l_line | sed -n -e '/^[0-9][0-9]*/ {
+	  p;
+	};'`"
+	if [ -z "$_l_percent" ]; then
+	  qdbus $DBUSREF org.kde.kdialog.ProgressDialog.setLabelText "$_l_line" 2> /dev/null;
+	else
+	  qdbus $DBUSREF Set org.kde.kdialog.ProgressDialog value "$_l_percent" 2> /dev/null;
+	fi
+      done
+    fi
   ;;
   dialog)
     while read _l_line; do
@@ -1129,4 +1145,4 @@ ssft_show_file() {
 }
 
 # ------
-# SVN Id: $Id: ssft.sh 73 2006-12-22 18:06:11Z sto $
+# SVN Id: $Id: ssft.sh 79 2009-06-10 20:01:45Z sto $
